# add missing see_also relation definitions
see_also_schema = schema.rschema("see_also")

if "Versionedfile" in schema:
    for ttype in ("Card", "Blog", "File", "Image", "Link", "Versionedfile"):
        if not see_also_schema.has_rdef("Versionedfile", ttype):
            add_relation_definition("Versionedfile", "see_also", ttype)

for ttype in ("Card", "Blog", "File", "Image", "Link"):
    if not see_also_schema.has_rdef("Image", ttype):
        add_relation_definition("Image", "see_also", ttype)



"""schema customization for the intranet application

:organization: Logilab
:copyright: 2003-2024 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
"""

__docformat__ = "restructuredtext en"

from yams.buildobjs import RelationDefinition
from yams.reader import context

from cubicweb_card.schema import Card
from cubicweb_blog.schema import BlogEntry
from cubicweb_file.schema import File
from cubicweb_link.schema import Link
from typing import Tuple

PERMISSIONS = {
    "read": (
        "managers",
        "users",
        "guests",
    ),
    "add": (
        "managers",
        "users",
    ),
    "delete": (
        "managers",
        "owners",
    ),
    "update": (
        "managers",
        "users",
        "owners",
    ),
}

Card.__permissions__ = PERMISSIONS
BlogEntry.__permissions__ = PERMISSIONS
File.__permissions__ = PERMISSIONS
Link.__permissions__ = PERMISSIONS


class interested_in(RelationDefinition):
    subject = "CWUser"
    object = "Event"


BASETYPES: Tuple[str, ...] = (
    "Card",
    "BlogEntry",
    "File",
    "Event",
    "Link",
    "Task",
    "Book",
)
if "VersionedFile" in context.defined:
    BASETYPES += ("VersionedFile",)
    from cubicweb_vcsfile.schema import VersionedFile, VersionContent

    VersionedFile.get_relation("name").fulltextindexed = True
    VersionContent.get_relation("data").fulltextindexed = True


class see_also(RelationDefinition):
    subject = BASETYPES
    object = BASETYPES


class comments(RelationDefinition):
    subject = "Comment"
    object = BASETYPES


class tags(RelationDefinition):
    subject = "Tag"
    object = BASETYPES



"""specific view classes for intranet

:organization: Logilab
:copyright: 2008-2024 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
"""

__docformat__ = "restructuredtext en"

from cubicweb.predicates import is_instance

from cubicweb_tag.views import TagsCloudBox

TagsCloudBox.visible = True
TagsCloudBox.__select__ = TagsCloudBox.__select__ & is_instance(
    "BlogEntry", "Link", "Card", "File"
)



add_relation_definition("Card", "see_also", "File")
add_relation_definition("Blog", "see_also", "File")
add_relation_definition("File", "see_also", "File")
add_relation_definition("Card", "see_also", "Link")
add_relation_definition("Blog", "see_also", "Link")
add_relation_definition("File", "see_also", "Link")
add_relation_definition("Link", "see_also", "Link")

synchronize_permissions("Blog")
synchronize_permissions("Card")
synchronize_permissions("File")
synchronize_permissions("Link")


rql("SET X see_also Y WHERE X concerns Y")

drop_relation_type("concerns")



"""intranet automatic tests"""

import unittest
import random

from cubicweb_web.devtools.testlib import AutomaticWebTest
from cubicweb.devtools.fill import ValueGenerator


class AutomaticWebTest(AutomaticWebTest):
    pass


def random_numbers(size):
    return "".join(random.choice("0123456789") for i in range(size))


class MyValueGenerator(ValueGenerator):
    def generate_Book_isbn10(self, entity, index):
        return random_numbers(10)

    def generate_Book_isbn13(self, entity, index):
        return random_numbers(13)


if __name__ == "__main__":
    unittest.main()



# pylint: disable-msg=W0622
"""cubicweb-intranet application packaging information"""

modname = "intranet"
distname = "cubicweb-intranet"

numversion = (2, 7, 1)
version = ".".join(str(num) for num in numversion)

license = "LGPL"
author = "Logilab"
author_email = "contact@logilab.fr"
description = "an intranet built on the CubicWeb framework"
web = "http://cubicweb.org/project/cubicweb-intranet"
classifiers = [
    "Environment :: Web Environment",
    "Framework :: CubicWeb",
    "Programming Language :: Python",
    "Programming Language :: JavaScript",
    "Programming Language :: Python :: 3",
    "Programming Language :: Python :: 3 :: Only",
]

__depends__ = {
    "cubicweb": ">=4.0.0,<5.0.0",
    "cubicweb-api": ">=0.12.0,<0.13.0",
    "cubicweb-blog": ">=3.0.0,<4.0.0",
    "cubicweb-book": ">=1.0.0,<2.0.0",
    "cubicweb-bootstrap": ">=2.0.0,<3.0.0",
    "cubicweb-card": ">=2.0.0,<3.0.0",
    "cubicweb-comment": ">=3.0.0,<4.0.0",
    "cubicweb-editorjs": ">=0.2.0,<0.3.0",
    "cubicweb-event": ">=2.0.0,<3.0.0",
    "cubicweb-file": ">=4.0.0,<5.0.0",
    "cubicweb-folder": ">=3.0.0,<4.0.0",
    "cubicweb-link": ">=2.0.0,<3.0.0",
    "cubicweb-localperms": ">=1.0.0,<2.0.0",
    "cubicweb-oauth2": ">=1.0.0,<2.0.0",
    "cubicweb-preview": ">=3.0.0,<4.0.0",
    "cubicweb-rqlcontroller": ">=1.0.0,<2.0.0",
    "cubicweb-searchui": ">=1.0.0,<2.0.0",
    "cubicweb-sentry": ">=1.0.0,<2.0.0",
    "cubicweb-signedrequest": ">=3.0.0,<4.0.0",
    "cubicweb-tag": ">=3.0.0,<4.0.0",
    "cubicweb-task": ">=2.0.0,<3.0.0",
    "cubicweb-prometheus": ">=0.5.0,<0.6.0",
}
